@@ -1,4 +1,3 @@
-import sys
 import os
 from datetime import datetime
 from pathlib import Path
@@ -6,7 +5,6 @@ from typing import Union
 from bson.json_util import dumps
 from edman.exceptions import EdmanFormatError
 
-
 class JsonManager:
     """
     JSONファイルの取扱いクラス
@@ -28,17 +26,13 @@ class JsonManager:
         if not isinstance(report_data, dict):
             raise EdmanFormatError('Not Dict Data')
 
-        date_str = ''
-        if date:
-            date_str = datetime.today().strftime("%Y%m%d%H%M%S%f") + '_'
-
+        date_str = datetime.today().strftime("%Y%m%d%H%M%S%f") + "_" if date else ""
         filename = date_str + name + '.json'
         p = path if isinstance(path, Path) else Path(path)
         savepath = p / filename
 
         with savepath.open("w", encoding='utf8') as file:
+            # TODO try except
             file.write(dumps(report_data, ensure_ascii=False, indent=4))
             file.flush()
             os.fsync(file.fileno())
-            sys.stdout.write('\r\n')  # tqdmとの干渉を防ぐための改行
-            print('saved:' + str(savepath))
